@@ -466,6 +466,9 @@ class Find(Base):
 
         # First we execute on a STUDY level to determine all the
         # STUDIES related to this query
+        series_uid                  = opt["SeriesInstanceUID"]
+        opt["SeriesInstanceUID"]    = ""
+        
         formattedStudiesResponse    = \
             self.systemlevel_run(opt,
                     {
@@ -490,7 +493,8 @@ class Find(Base):
                             {
                                 'f_commandGen':         self.findscu_command,
                                 'QueryRetrieveLevel':   'SERIES',
-                                'StudyInstanceUID':     study['StudyInstanceUID']['value']
+                                'StudyInstanceUID':     study['StudyInstanceUID']['value'],
+                                'SeriesInstanceUID':    series_uid
                             }
                     )
                 for series in formattedSeriesResponse['data']:
